bayespy.inference.vmp.transformations.RotateGaussian
====================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. autoclass:: RotateGaussian

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~RotateGaussian.__init__
      ~RotateGaussian.bound
      ~RotateGaussian.get_bound_terms
      ~RotateGaussian.nodes
      ~RotateGaussian.rotate
      ~RotateGaussian.setup
   
   

   
   
   